@@ -12,7 +12,7 @@
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
 --
--- Copyright (C) 2015-present, TBOOX Open Source Group.
+-- Copyright (C) 2015-present, Xmake Open Source Community.
 --
 -- @author      ruki
 -- @file        ping.lua
@@ -23,19 +23,23 @@ import("core.cache.detectcache")
 import("lib.detect.find_tool")
 import("async.runjobs")
 
--- ping host
-function _ping(ping, host)
+-- using ping to ping host
+function _ping_via_ping(ping, host)
     local data = nil
     if is_host("windows") then
         data = try { function () return os.iorun("%s -n 1 -w 1000 %s", ping.program, host) end }
     elseif is_host("macosx") then
         data = try { function () return os.iorun("%s -c 1 -t 1 %s", ping.program, host) end }
     else
-        data = try { function () return os.iorun("%s -c 1 -W 1 %s", ping.program, host) end }
+        -- @see https://github.com/xmake-io/xmake/issues/4470#issuecomment-1840338777
+        data = try { function () return os.iorun("%s -c 1 -W 1 -n %s", ping.program, host) end }
+        if not data then
+            data = try { function () return os.iorun("%s -c 1 -W 1 %s", ping.program, host) end }
+        end
     end
     local timeval = "65535"
     if data then
-        timeval = data:match("time[=<]([%d%s%.]-)ms", 1, true) or data:match("[=<]([%d%s%.]-)ms TTL", 1, true) or "65535"
+        timeval = data:match("= [^/]+/([^/]+)/", 1, true) or data:match("[=<]([%d%s%.]-)ms TTL", 1, true) or "65535"
     end
     if timeval then
         timeval = tonumber(timeval:trim())
@@ -43,6 +47,57 @@ function _ping(ping, host)
     return timeval
 end
 
+-- using curl to ping host
+function _ping_via_curl(curl, host)
+    local data, dt = try { function ()
+        local t = os.mclock()
+        local tmpfile = os.tmpfile()
+        local outdata = os.iorunv(curl.program, {"-o", tmpfile, "-s", "-w", "%{time_total}", "--max-time", "1", host})
+        t = os.mclock() - t
+        os.tryrm(tmpfile)
+        return outdata, t
+    end }
+    local timeval = 65535
+    if data then
+        local t = tonumber(data:trim())
+        if t then
+            timeval = t * 1000
+        else
+            timeval = dt
+        end
+    end
+    return timeval
+end
+
+-- using wget to ping host
+function _ping_via_wget(wget, host)
+    local data = try { function ()
+        local t = os.mclock()
+        os.runv(wget.program, {"-O", os.nuldev(), "--timeout=1", host})
+        t = os.mclock() - t
+        return t
+    end }
+    local timeval = 65535
+    if data then
+        timeval = data
+    end
+    return timeval
+end
+
+-- ping host
+-- @see https://github.com/xmake-io/xmake/issues/6579
+function _ping(ping, host)
+    local routers = {
+        ping = _ping_via_ping,
+        curl = _ping_via_curl,
+        wget = _ping_via_wget
+    }
+    local router = routers[ping.name] or _ping_via_ping
+    if router then
+        return router(ping, host)
+    end
+end
+
 -- send ping to hosts
 --
 -- @param hosts     the hosts
@@ -51,9 +106,9 @@ end
 -- @return          the time or -1
 --
 function main(hosts, opt)
-
     opt = opt or {}
-    local ping = find_tool("ping", opt)
+
+    local ping = find_tool("curl", opt) or find_tool("wget") or find_tool("ping", opt)
     if not ping then
         return {}
     end
